@@ -20,7 +20,8 @@ VOICE = "en-GB-SoniaNeural"
 OUTPUT_FILE = "test.mp3"
 
 
-async def _main() -> None:
+async def amain() -> None:
+    """Main function"""
     communicate = edge_tts.Communicate(TEXT, VOICE)
     with open(OUTPUT_FILE, "wb") as file:
         async for chunk in communicate.stream():
@@ -31,4 +32,8 @@ async def _main() -> None:
 
 
 if __name__ == "__main__":
-    asyncio.get_event_loop().run_until_complete(_main())
+    loop = asyncio.get_event_loop_policy().get_event_loop()
+    try:
+        loop.run_until_complete(amain())
+    finally:
+        loop.close()
