@@ -13,10 +13,15 @@ VOICE = "en-GB-SoniaNeural"
 OUTPUT_FILE = "test.mp3"
 
 
-async def _main() -> None:
+async def amain() -> None:
+    """Main function"""
     communicate = edge_tts.Communicate(TEXT, VOICE)
     await communicate.save(OUTPUT_FILE)
 
 
 if __name__ == "__main__":
-    asyncio.get_event_loop().run_until_complete(_main())
+    loop = asyncio.get_event_loop_policy().get_event_loop()
+    try:
+        loop.run_until_complete(amain())
+    finally:
+        loop.close()
