@@ -17,7 +17,8 @@ OUTPUT_FILE = "test.mp3"
 WEBVTT_FILE = "test.vtt"
 
 
-async def _main() -> None:
+async def amain() -> None:
+    """Main function"""
     communicate = edge_tts.Communicate(TEXT, VOICE)
     submaker = edge_tts.SubMaker()
     with open(OUTPUT_FILE, "wb") as file:
@@ -32,4 +33,8 @@ async def _main() -> None:
 
 
 if __name__ == "__main__":
-    asyncio.get_event_loop().run_until_complete(_main())
+    loop = asyncio.get_event_loop_policy().get_event_loop()
+    try:
+        loop.run_until_complete(amain())
+    finally:
+        loop.close()
