@@ -15,7 +15,7 @@ from edge_tts import Communicate, SubMaker, list_voices
 async def _print_voices(*, proxy: str) -> None:
     """Print all available voices."""
     voices = await list_voices(proxy=proxy)
-    voices = sorted(voices, key=lambda voice: voice["ShortName"])
+    voices = sorted(voices, key=lambda voice: voice["ShortName"])  # type: ignore
     for idx, voice in enumerate(voices):
         if idx != 0:
             print()
@@ -36,6 +36,21 @@ async def _print_voices(*, proxy: str) -> None:
 
 async def _run_tts(args: Any) -> None:
     """Run TTS after parsing arguments from command line."""
+
+    try:
+        if sys.stdin.isatty() and sys.stdout.isatty() and not args.write_media:
+            print(
+                "Warning: TTS output will be written to the terminal. "
+                "Use --write-media to write to a file.\n"
+                "Press Ctrl+C to cancel the operation. "
+                "Press Enter to continue.",
+                file=sys.stderr,
+            )
+            input()
+    except KeyboardInterrupt:
+        print("\nOperation canceled.", file=sys.stderr)
+        return
+
     tts: Communicate = Communicate(
         args.text,
         args.voice,
@@ -43,7 +58,7 @@ async def _run_tts(args: Any) -> None:
         rate=args.rate,
         volume=args.volume,
     )
-    subs: SubMaker = SubMaker(args.overlapping)
+    subs: SubMaker = SubMaker()
     with open(
         args.write_media, "wb"
     ) if args.write_media else sys.stdout.buffer as audio_file:
@@ -59,10 +74,11 @@ async def _run_tts(args: Any) -> None:
         else sys.stderr
     )
     with sub_file:
-        sub_file.write(subs.generate_subs())
+        sub_file.write(subs.generate_subs(args.words_in_cue))
 
 
-async def _async_main() -> None:
+async def amain() -> None:
+    """Async main function"""
     parser = argparse.ArgumentParser(description="Microsoft Edge TTS")
     group = parser.add_mutually_exclusive_group(required=True)
     group.add_argument("-t", "--text", help="what TTS will say")
@@ -82,10 +98,9 @@ async def _async_main() -> None:
     parser.add_argument("--rate", help="set TTS rate. Default +0%%.", default="+0%")
     parser.add_argument("--volume", help="set TTS volume. Default +0%%.", default="+0%")
     parser.add_argument(
-        "-O",
-        "--overlapping",
-        help="overlapping subtitles in seconds. Default: 0.",
-        default=0,
+        "--words-in-cue",
+        help="number of words in a subtitle cue. Default: 10.",
+        default=10,
         type=float,
     )
     parser.add_argument(
@@ -117,7 +132,11 @@ async def _async_main() -> None:
 
 def main() -> None:
     """Run the main function using asyncio."""
-    asyncio.get_event_loop().run_until_complete(_async_main())
+    loop = asyncio.get_event_loop_policy().get_event_loop()
+    try:
+        loop.run_until_complete(amain())
+    finally:
+        loop.close()
 
 
 if __name__ == "__main__":
